@@ -31,12 +31,89 @@ def 图形化窗口位置(x,y):
 def 刷新窗口():
     window.update()
 '''
-with open('trandic.json', 'r', encoding='utf-8') as f:
-    trandic = json.load(f)
-with open('retrandic.json', 'r', encoding='utf-8') as f:
-    replace_trandic = json.load(f)
-with open('keywords.json', 'r', encoding='utf-8') as f:
-    custom_keywords = json.load(f)
+
+trandic = {
+    "遍历": "for",
+    "在": "in",
+    "定义": "def",
+    "类": "class",
+    "继承": "extends",
+    "如果": "if",
+    "返回": "return",
+    "退出循环": "break",
+    "跳过": "continue",
+    "触发异常": "raise",
+    "导入": "import",
+    "从": "from",
+    "到": "to",
+    "结束": "end",
+    "当": "as",
+    "等于": "==",
+    "不等于": "!=",
+    "大于": ">",
+    "小于": "<",
+    "大于等于": ">=",
+    "小于等于": "<=",
+    "与": "and",
+    "或": "or",
+    "非": "not",
+    "和": "and",
+    "缩进": "   ",
+    "所有": "*",
+    "如果循环": "while",
+    "否则":"else",
+    "否则如果":"elif"
+}
+
+replace_trandic = {
+    "”": "\"",
+    "“": "\"",
+    "‘": "'",
+    "’": "'",
+    "（": "(",
+    "）": ")",
+    "，": ",",
+    "：": ":",
+    "；": ";",
+    "【": "[",
+    "】": "]",
+    "。": ".",
+    "输出": "print",
+    "输入": "input",
+    "转整数": "int",
+    "转浮点数": "float",
+    "转字符串": "str",
+    "转布尔": "bool",
+    "转列表": "list",
+    "转元组": "tuple",
+    "转字典": "dict",
+    "转集合": "set",
+    "转比特": "bytes",
+    "转字节": "bytearray",
+    "真": "True",
+    "假": "False",
+    "无": "None",
+    "范围": "range",
+    "请求网页": "get__.urlopen",
+    "获取内容": "read()",
+    "随机数": "random.randint",
+    "占位符": "pass",
+    "加": "+",
+    "减": "-",
+    "乘": "*",
+    "除": "/",
+    "取余": "%",
+    "取整": "//",
+    "次方": "**",
+    "等待": "time.sleep",
+    "长度":"len",
+    "++":"+=1",
+    "！=":"!="
+}
+custom_keywords = [
+["多线程", 2  , "Thread(None,%s,None,%s).start()", "threading"],
+["输出"  , 1  , "print(%s)"                      , "_"        ]
+]
 keywords=[]
 for item in custom_keywords:keywords.append(item[0])
 def zlcytopy(line,linenum,libusedict):
