@@ -1,6 +1,10 @@
 import json,zlcython,errentozh
-with open('./liblist.json', 'r', encoding='utf-8') as f:
-    libusedict = json.load(f)
+libusedict = {"urllib_request": [False, "import urllib.request as get__"],
+    "random": [False, "import random"],
+    "time": [False, "import time"],
+    "threading": [False, "from threading import Thread"],
+    "_": [False, ""]
+}
 zlcython='''Zlcython 2.2.0 (tags/v2.2.0)
 Type ".exit" or press Control+C to exit.
 Copyright (c) 2022, LucasZ228.
